@@ -2,6 +2,7 @@
 
 import logging
 import subprocess
+import sys
 
 # Readline is only available on Unix
 try:
@@ -247,14 +248,9 @@ def interactive_loop(
                     continue
 
                 if command_lower == "exec":
-                    set_suspend_sigterm(suspend=True)
                     if len(command) > 1:
-                        try:
-                            logging.info("Running command: '{}'".format(command[1:]))
-                            subprocess.run(command[1:])
-                        except Exception as e:
-                            print(e)
-                    set_suspend_sigterm(suspend=False)
+                        _exec(command[1:])
+                        print()
                     continue
 
                 if command_lower == "cd":
@@ -304,14 +300,6 @@ def interactive_loop(
                     pushed = False
                     continue
 
-                if command_lower == "track_follow":
-                    track_follow(
-                        speaker,
-                        use_local_speaker_list=use_local_speaker_list,
-                        break_on_pause=True,
-                    )
-                    continue
-
                 # Alias creation, update, and deletion
                 if command_lower == "alias":
                     if len(command) == 1:
@@ -423,25 +411,28 @@ def interactive_loop(
 
                     action = args.pop(0).lower()
                     logging.info("Action = '{}'; args = {}".format(action, args))
-                    exit_code, output, error_msg = run_command(
-                        speaker,
-                        action,
-                        *args,
-                        use_local_speaker_list=use_local_speaker_list,
-                    )
-                    if exit_code:
-                        if not error_msg == "":
-                            print(error_msg)
+                    if action == "track_follow":
+                        _track_follow(speaker.ip_address)
                     else:
-                        if not output == "":
-                            print(output)
-                        if action == "rename":
-                            speaker_name = speaker.get_speaker_info(refresh=True)[
-                                "zone_name"
-                            ]
-                            _set_actions_and_commands_list(
-                                use_local_speaker_list=use_local_speaker_list
-                            )
+                        exit_code, output, error_msg = run_command(
+                            speaker,
+                            action,
+                            *args,
+                            use_local_speaker_list=use_local_speaker_list,
+                        )
+                        if exit_code:
+                            if not error_msg == "":
+                                print(error_msg)
+                        else:
+                            if not output == "":
+                                print(output)
+                            if action == "rename":
+                                speaker_name = speaker.get_speaker_info(refresh=True)[
+                                    "zone_name"
+                                ]
+                                _set_actions_and_commands_list(
+                                    use_local_speaker_list=use_local_speaker_list
+                                )
                     if temp_active_speaker:
                         logging.info(
                             "Unsetting temporary active speaker: '{}'".format(
@@ -453,6 +444,7 @@ def interactive_loop(
                         speaker_name = None
                 except:
                     print("Error: Invalid command")
+
         # Catch all exceptions in the interactive loop
         except Exception as e:
             print("Error: {}".format(e))
@@ -558,9 +550,8 @@ This is SoCo-CLI interactive mode. Interactive commands are as follows:
                     or just enter '0'.
     'sk'         :  Enters 'single keystroke' mode. (Also 'single-keystroke'.)
     'speakers'   :  List the names of all available speakers.
-    'track_follow' : Prints the track details each time they change. Execution
-                    stops when speaker playback ends. Termination using
-                    CTRL-C will exit the interactive shell.
+    'track_follow' : Prints the track details each time they change. Runs in a
+                     subprocess. Terminate execution using CTRL-C.
     'version'    :  Print the versions of SoCo-CLI, SoCo, and Python in use.
     
     The action syntax is the same as when using 'sonos' from the command line.
@@ -766,3 +757,41 @@ def _rescan(use_local_speaker_list=False, max=False):
         _set_actions_and_commands_list(use_local_speaker_list=use_local_speaker_list)
     except Exception as e:
         print("Rescan failed: please check your network connection [{}]".format(e))
+
+
+def _exec(command_line):
+    """Runs a command as a subprocess.
+
+    Args:
+        command_line (list): The command to execute.
+    """
+    set_suspend_sigterm(suspend=True)
+    try:
+        logging.info("Running command: '{}'".format(command_line))
+        subprocess.run(command_line)
+    except Exception as e:
+        print(e)
+    set_suspend_sigterm(suspend=False)
+
+
+def _track_follow(speaker_ip):
+    # This runs in a subprocess, to allow CTRL-C
+    # to exit the subprocess only, and not the shell.
+
+    command_line = [sys.argv[0]]  # Path to 'sonos'
+    command_line.append(speaker_ip)
+    command_line.append("track_follow")
+    for position, arg in enumerate(sys.argv[1:]):
+        if arg.startswith("--log="):
+            command_line.append(arg)
+            break
+        elif arg == "--log":
+            command_line.append(arg)
+            command_line.append(sys.argv[1:][position + 1])
+            break
+
+    print(
+        "\n Running 'track_follow' in a subprocess. Terminate using CTRL-C."
+    )
+    _exec(command_line)
+    print()
